@@ -404,7 +404,6 @@ class Consumer:
         self.callback = callback
         self.type = type
         self.nowait = nowait
-        rabbit_quorum_queue_config = rabbit_quorum_queue_config or {}
         self.queue_arguments = _get_queue_arguments(
             rabbit_ha_queues, rabbit_queue_ttl, rabbit_quorum_queue,
             rabbit_quorum_queue_config, rabbit_stream_fanout)
@@ -419,7 +418,7 @@ class Consumer:
         self.rabbit_stream_fanout = rabbit_stream_fanout
         self.next_stream_offset = "last"
 
-    def _declare_fallback(self, err, conn, consumer_arguments):
+    def _declare_fallback_nondurable(self, err, conn, consumer_arguments):
         """Fallback by declaring a non durable queue.
 
         When a control exchange is shared between services it is possible
@@ -431,26 +430,25 @@ class Consumer:
         to fallback by creating a non durable queue to match the default
         config.
         """
-        if "PRECONDITION_FAILED - inequivalent arg 'durable'" in str(err):
-            LOG.info(
-                "[%s] Retrying to declare the exchange (%s) as "
-                "non durable", conn.connection_id, self.exchange_name)
-            self.exchange = kombu.entity.Exchange(
-                name=self.exchange_name,
-                type=self.type,
-                durable=False,
-                auto_delete=self.queue_auto_delete)
-            self.queue = kombu.entity.Queue(
-                name=self.queue_name,
-                channel=conn.channel,
-                exchange=self.exchange,
-                durable=False,
-                auto_delete=self.queue_auto_delete,
-                routing_key=self.routing_key,
-                queue_arguments=self.queue_arguments,
-                consumer_arguments=consumer_arguments
-            )
-            self.queue.declare()
+        LOG.info(
+            "[%s] Retrying to declare the exchange (%s) as "
+            "non durable", conn.connection_id, self.exchange_name)
+        self.exchange = kombu.entity.Exchange(
+            name=self.exchange_name,
+            type=self.type,
+            durable=False,
+            auto_delete=self.queue_auto_delete)
+        self.queue = kombu.entity.Queue(
+            name=self.queue_name,
+            channel=conn.channel,
+            exchange=self.exchange,
+            durable=False,
+            auto_delete=self.queue_auto_delete,
+            routing_key=self.routing_key,
+            queue_arguments=self.queue_arguments,
+            consumer_arguments=consumer_arguments
+        )
+        self.queue.declare()
 
     def reset_stream_offset(self):
         if not self.rabbit_stream_fanout:
@@ -493,16 +491,21 @@ class Consumer:
             try:
                 self.queue.declare()
             except amqp_ex.PreconditionFailed as err:
-                # NOTE(hberaud): This kind of exception may be triggered
-                # when a control exchange is shared between services and
-                # when services try to create it with configs that differ
-                # from each others. RabbitMQ will reject the services
-                # that try to create it with a configuration that differ
-                # from the one used first.
-                LOG.warning('[%s] Queue %s could not be declared probably '
-                            'because of conflicting configurations: %s',
-                            conn.connection_id, self.queue_name, err)
-                self._declare_fallback(err, conn, consumer_arguments)
+                if "PRECONDITION_FAILED - inequivalent arg 'durable'" in \
+                        str(err):
+                    # NOTE(hberaud): This kind of exception may be triggered
+                    # when a control exchange is shared between services and
+                    # when services try to create it with configs that differ
+                    # from each others. RabbitMQ will reject the services
+                    # that try to create it with a configuration that differ
+                    # from the one used first.
+                    LOG.warning('[%s] Queue %s could not be declared probably '
+                                'because of conflicting configurations: %s',
+                                conn.connection_id, self.queue_name, err)
+                    self._declare_fallback_nondurable(
+                        err, conn, consumer_arguments)
+                else:
+                    raise
             except amqp_ex.NotFound as ex:
                 # NOTE(viktor.krivak): This exception is raised when
                 # non-durable and non-ha queue is hosted on node that
@@ -1089,8 +1092,8 @@ class Connection:
             retry = float('inf')
 
         def on_error(exc, interval):
-            LOG.debug("[%s] Received recoverable error from kombu:"
-                      % self.connection_id,
+            LOG.debug("[%s] Received recoverable error from kombu:",
+                      self.connection_id,
                       exc_info=True)
 
             recoverable_error_callback and recoverable_error_callback(exc)
@@ -1245,7 +1248,7 @@ class Connection:
                 for consumer in filter(lambda c: c.type == 'fanout',
                                        self._consumers):
                     LOG.debug('[connection close] Deleting fanout '
-                              'queue: %s ' % consumer.queue.name)
+                              'queue: %s ', consumer.queue.name)
                     consumer.queue.delete()
             self._set_current_channel(None)
             self.connection.release()
@@ -1300,8 +1303,8 @@ class Connection:
             sock = self.channel.connection.sock
         except AttributeError as e:
             # Level is set to debug because otherwise we would spam the logs
-            LOG.debug('[%s] Failed to get socket attribute: %s'
-                      % (self.connection_id, str(e)))
+            LOG.debug('[%s] Failed to get socket attribute: %s',
+                      self.connection_id, e)
         else:
             sock.settimeout(timeout)
             # TCP_USER_TIMEOUT is not defined on Windows and Mac OS X
@@ -1367,7 +1370,7 @@ class Connection:
                         # already do that for other connection
                         try:
                             self.connection.drain_events(timeout=0.001)
-                        except socket.timeout:
+                        except TimeoutError:
                             pass
                     # NOTE(hberaud): In a clustered rabbitmq when
                     # a node disappears, we get a ConnectionRefusedError
@@ -1377,9 +1380,7 @@ class Connection:
                     # Catch these exceptions to ensure that we call
                     # ensure_connection for switching the
                     # connection destination.
-                    except (socket.timeout,
-                            ConnectionRefusedError,
-                            OSError,
+                    except (TimeoutError, ConnectionRefusedError, OSError,
                             kombu.exceptions.OperationalError,
                             amqp_ex.ConnectionForced) as exc:
                         LOG.info("A recoverable connection/channel error "
@@ -1463,7 +1464,7 @@ class Connection:
                 try:
                     self.connection.drain_events(timeout=poll_timeout)
                     return
-                except socket.timeout:
+                except TimeoutError:
                     poll_timeout = timer.check_return(
                         _raise_timeout, maximum=self._poll_timeout)
                 except self.connection.channel_errors as exc:
@@ -1534,7 +1535,7 @@ class Connection:
                 unique = self._q_manager.get()
             else:
                 unique = uuid.uuid4().hex
-            queue_name = '{}_fanout_{}'.format(topic, unique)
+            queue_name = f'{topic}_fanout_{unique}'
         LOG.debug('Creating fanout queue: %s', queue_name)
 
         is_durable = (self.rabbit_transient_quorum_queue or
@@ -1599,17 +1600,19 @@ class Connection:
             try:
                 exchange(self.channel).declare()
             except amqp_ex.PreconditionFailed as err:
-                # NOTE(hberaud): This kind of exception may be triggered
-                # when a control exchange is shared between services and
-                # when services try to create it with configs that differ
-                # from each others. RabbitMQ will reject the services
-                # that try to create it with a configuration that differ
-                # from the one used first.
                 if "PRECONDITION_FAILED - inequivalent arg 'durable'" \
                    in str(err):
+                    # NOTE(hberaud): This kind of exception may be triggered
+                    # when a control exchange is shared between services and
+                    # when services try to create it with configs that differ
+                    # from each others. RabbitMQ will reject the services
+                    # that try to create it with a configuration that differ
+                    # from the one used first.
                     LOG.warning("Force creating a non durable exchange.")
                     exchange.durable = False
                     exchange(self.channel).declare()
+                else:
+                    raise
             self._declared_exchanges.add(exchange.name)
 
         log_info = {'msg': msg,
